/**
 * \file /gui/tandem_run_dialog/tandem_run_dialog.cpp
 * \date 31/8/2017
 * \author Olivier Langella
 * \brief dialog window to launch tandem process
 */

/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/
#include "tandemrundialog.h"

#include "ui_tandem_run_dialog.h"
#include <QDebug>
#include <QSettings>
#include <QFileDialog>
#include <QMessageBox>
#include <pappsomspp/pappsoexception.h>


TandemRunDialog::TandemRunDialog(QWidget * parent):
    QDialog(parent),
    ui(new Ui::TandemRunDialog)
{
    qDebug() << "TandemRunDialog::TandemRunDialog begin";
    ui->setupUi(this);
    this->setModal(true);
    _p_fasta_file_list = new QStringListModel();
    
#if QT_VERSION >= 0x050000
    // Qt5 code
    /*
    connect(&workerThread, &QThread::finished, worker, &QObject::deleteLater);
    connect(this, &PtSpectrumViewer::operateMsDataFile, worker, &PwizLoaderThread::doMsDataFileLoad);
    connect(worker, &PwizLoaderThread::msDataReady, this, &PtSpectrumViewer::handleMsDataFile);
    */
#else
// Qt4 code

#endif

    qDebug() << "TandemRunDialog::TandemRunDialog end";
}

TandemRunDialog::~TandemRunDialog()
{
    delete ui;
}

void TandemRunDialog::selectFastaFiles() {
    try {
        QSettings settings;
        QString default_location = settings.value("path/tandemrun_fastafiles_directory", "").toString();

        QStringList filenames = QFileDialog::getOpenFileNames(this,tr("FASTA files"),default_location,
                                tr("FASTA files (*.fasta);;all files (*)") );

        if (filenames.size() > 0) {
            settings.setValue("path/tandemrun_fastafiles_directory", QFileInfo(filenames[0]).absolutePath());
        }
        _p_fasta_file_list->setStringList(filenames);
        ui->fasta_file_listview->setModel(_p_fasta_file_list);

    }
    catch (pappso::PappsoException & error) {
        //QMessageBox::warning(this,
        //                  tr("Error choosing identification result files : %1").arg(error.qwhat()), error);
    }
}
